@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '4.4';
+$BZ::Client::VERSION = '4.4001';
 
 use BZ::Client::XMLRPC;
 use BZ::Client::Exception;
@@ -294,7 +294,7 @@ BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 4.4
+version 4.4001
 
 =head1 SYNOPSIS
 
@@ -539,6 +539,10 @@ This is used internally to set cookies with the log in functions. Don't touch th
 
 =back
 
+=head1 EXCEPTION HANDLING
+
+See L<BZ::Client::Exception>
+
 =head1 ERROR CODES
 
 =head2 300 (Invalid Username or Password)
@@ -583,7 +587,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
