@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::FlagType;
-$BZ::Client::FlagType::VERSION = '4.4';
+$BZ::Client::FlagType::VERSION = '4.4001';
 
 use parent qw( BZ::Client::API );
 
@@ -44,7 +44,7 @@ BZ::Client::FlagType - The API for creating, changing, and getting info on Flags
 
 =head1 VERSION
 
-version 4.4
+version 4.4001
 
 =head1 SYNOPSIS
 
@@ -494,7 +494,11 @@ This flag type is not available for the products you can administer. Therefore y
 
 =head1 INSTANCE METHODS
 
-Not yet implemented
+FIXME Not yet implemented
+
+=head1 EXCEPTION HANDLING
+
+See L<BZ::Client::Exception>
 
 =head1 SEE ALSO
 
@@ -516,7 +520,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
