@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::User;
-$BZ::Client::User::VERSION = '4.4';
+$BZ::Client::User::VERSION = '4.4001';
 
 use parent qw( BZ::Client::API );
 
@@ -82,7 +82,7 @@ BZ::Client::User - Creates and edits user accounts in Bugzilla
 
 =head1 VERSION
 
-version 4.4
+version 4.4001
 
 =head1 SYNOPSIS
 
@@ -478,6 +478,10 @@ Logged-in users are not authorized to edit other users.
 
 =back
 
+=head1 EXCEPTION HANDLING
+
+See L<BZ::Client::Exception>
+
 =head1 SEE ALSO
 
 L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/User.html>
@@ -498,7 +502,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2017 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
